package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````,`MP`!````*"0```````!``````````.BA````
M`````````$``.``(`$``&@`9``8````%````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````;`````````!L``````````0`````````!````
M!0````````````````````````````````````27````````!)<`````````
M``$```````$````&````Z)H```````#HF@$``````.B:`0``````T`4`````
M````%@```````````0```````@````8`````FP````````";`0```````)L!
M``````!0`@```````%`"````````"``````````$````!````!P"````````
M'`(````````<`@```````$0`````````1``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```#HF@```````.B:`0``````Z)H!```````8!0``````
M`!@%`````````0`````````O;&EB+VQD+6QI;G5X+6%A<F-H-C0N<V\N,0``
M!````!`````!````1TY5```````#````!P`````````$````%`````,```!'
M3E4`3/[(K@?AG2G$8RP'Q,$B[.3K"$,1````40````0````(````(1`0``7`
M!(0H`A`!@(9`@((I``0)(`2)B*`81;H$`@A1````4@```%8```!;````7```
M`&,```!D````90```&<```!H`````````&H```!K````;````&X`````````
M``````&O-.ANQ=\?ZM/O#L[>1RUK?YI\+L6;MG94/)0@_^0.N(WQ#M5DU'S9
M<5@<XD?&`:Q+X\"ZXY)\6.^7><+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'
M<-,-%.*>VLWCGC-BV^T-.I<+?ZF<F[[:5QOAIP(*H^#[20``````````````
M`````````````````````````````P`+`*`=````````````````````````
M`P`3`/B:`0````````````````#H`@``$@````````````````````````!L
M`P``$@````````````````````````"X`@``$@``````````````````````
M``"_`@``$@````````````````````````!>`P``$@``````````````````
M``````!?`@``$@`````````````````````````1````(```````````````
M```````````0`P``$@`````````````````````````H`P``$@``````````
M``````````````!/`P``(@`````````````````````````A`P``$@``````
M```````````````````(`P``$@````````````````````````#(````$@``
M```````````````````````:`P``$0````````````````````````"7`0``
M$@````````````````````````!-`@``$@````````````````````````!L
M`@``$@````````````````````````"8````$@``````````````````````
M```@`0``$@`````````````````````````Q`P``$@``````````````````
M``````"Q`@``$@````````````````````````"^`0``$@``````````````
M```````````5`0``$0````````````````````````#O`@``$@``````````
M``````````````![`0``$@````````````````````````#W````$0``````
M``````````````````!)`0``$@````````````````````````!D`@``$@``
M``````````````````````""`P``$@````````````````````````#&`@``
M$@````````````````````````#6````$@````````````````````````#%
M`0``$@`````````````````````````V`@``$@``````````````````````
M``"R`0``$@`````````````````````````$`@``$@``````````````````
M``````"<`@``$@````````````````````````!U`@``$@``````````````
M``````````!^`@``$@`````````````````````````8`@``$@``````````
M``````````````!7`0``$@`````````````````````````M````(```````
M``````````````````"T`P``$0````````````````````````"5`P``(0``
M``````````````````````"D`@``$@````````````````````````!T`P``
M$@````````````````````````#0`0``$0````````````````````````!X
M````$@````````````````````````#:`@``$@``````````````````````
M``![`P``$@````````````````````````!!!```$@``````````````````
M``````#4`@``$@````````````````````````"G````$@``````````````
M``````````"S````$@````````````````````````!P`0``$@``````````
M``````````````#]`@``$@`````````````````````````V`0``$@``````
M```````````````````E`0``$@````````````````````````!J````$@``
M``````````````````````!%`P``$@`````````````````````````J`0``
M$@````````````````````````"G`0``$@`````````````````````````$
M`0``$@`````````````````````````^`P``$@``````````````````````
M``")`0``$@````````````````````````"'````$@``````````````````
M```````^`@``$@````````````````````````"J`@``$@``````````````
M``````````"4`P``$0````````````````````````"6`P``$0``````````
M```````````````\````(``````````````````````````>`@``$@``````
M``````````````````#H````$@````````````````````````!G`0``$@``
M``````````````````````#-`@``$@````````````````````````!0````
M(``````````````````````````E`@``$@````````````````````````"/
M`@``$@````````````````````````"6`@``$@``````````````````````
M``#V`P``$``7`.BP`0````````````````!*!```$@`-`.!3````````B```
M```````8!```$@`.``15``````````````````!O!```$@`-`)A&````````
MI`D```````"/`P``$@`-`.`A````````2`(````````>!```$@`-`!@_````
M````!`````````#G`P``$``7`+B@`0````````````````#=!```$@`-`"`_
M````````)`(```````#7!```$@`+`*`=```````````````````*!0``$@`-
M`$!0````````G`,```````#;`P``$``7`+B@`0````````````````!6!```
M$@`-`$A!````````(`````````")!```$0`/`!A5````````!``````````)
M!```$``7`.BP`0`````````````````!!```$``7`.BP`0``````````````
M``#5!```$@`-`*`]````````.`````````#J!```$@`-`$!%````````5`$`
M``````#\!```$@`-`(!$````````F`````````!\!```$``6``"@`0``````
M``````````!C!```$@`-`&A!````````.`$```````#4`P``$``6`+B@`0``
M``````````````"^!```$0`6`+"@`0``````"``````````.!```$@`-``!5
M````````!`````````"N!```$@`-`(A4````````>`````````""!```$@`-
M`"@D``````````````````!^!```(``6``"@`0`````````````````O!```
M$@`-`!A%````````*`````````#U`P``$``7`.BP`0````````````````"8
M!```$@`-`#`^````````Y`````````#(!```$@`-`*!"````````X`$`````
M````;&EB<&5R;"YS;RXU+C(T`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?<F5G
M:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET
M,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V
M`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R
M<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W
M6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R
M;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V
M`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E
M=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA
M;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L+G-O+C(`;&EB
M;2YS;RXV`&QI8G!T:')E860N<V\N,`!P=&AR96%D7V=E='-P96-I9FEC`&-L
M;W-E`&]P96XV-`!?7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`<F5A9`!L:6)C
M+G-O+C8`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P
M`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL
M;V,`86)O<G0`;65M8VAR`&=E='!I9`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S
M=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H
M:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`
M<F5A9&QI;FL`7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]C>&%?
M9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``
M7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`&QD+6QI;G5X+6%A<F-H-C0N
M<V\N,0!?7W-T86-K7V-H:U]G=6%R9`!L:6)C<GEP="YS;RXQ`%]E9&%T80!?
M7V)S<U]S=&%R=`!?7V)S<U]S=&%R=%]?`%]?8G-S7V5N9%]?`%]?96YD7U\`
M7V5N9`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G971?=7-E
M<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!P87)?8F%S96YA;64`
M<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!?24]?<W1D
M:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET
M`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`
M<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?
M4$%27T)/3U0`1TQ)0D-?,BXQ-P```````````@`"``(``@`"``(````"``(`
M`@`"``(````"`````@`"```````"``(``@````(``````````@`"``(`````
M``,````#``(``@`"``,```````0``@`"``(```````(``@`"``(`````````
M`@````(````"``````````(```````,``@`"``(````#```````"`````P`"
M``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``````````0`!`)X#```0````(````)>1E@8`
M``0`(`4````````!``$`]`$``!`````@````EY&6!@```P`@!0````````$`
M`0!#`@``$`````````"7D98&```"`"`%````````Z)H!```````#!```````
M`#@E````````\)H!```````#!````````/`D````````<)\!```````#!```
M``````!5````````N)\!```````#!`````````B@`0``````R)\!```````#
M!````````(A4````````V)\!```````#!````````.`A````````"*`!````
M```#!`````````B@`0``````&*`!```````#!````````#!9````````(*`!
M```````#!````````$!9````````**`!```````#!````````$A9````````
M,*`!```````#!````````%!9````````.*`!```````#!````````%A9````
M````0*`!```````#!````````'!9````````4*`!```````#!````````"A9
M````````6*`!```````#!````````,!5````````:*`!```````#!```````
M`-!6````````<*`!```````#!`````````A9````````>*`!```````#!```
M`````!!9````````@*`!```````#!````````!A9````````B*`!```````#
M!````````"!9````````F*`!```````#!````````/!8````````H*`!````
M```#!````````/A8````````L*`!```````#!````````(!9````````>)\!
M```````!!```"0``````````````@)\!```````!!```#```````````````
MB)\!```````!!```$```````````````D)\!```````!!```$0``````````
M````F)\!```````!!```&0``````````````H)\!```````!!```'```````
M````````J)\!```````!!```*P``````````````L)\!```````!!```+```
M````````````P)\!```````!!```,```````````````T)\!```````!!```
M.@``````````````X)\!```````!!```0P``````````````Z)\!```````!
M!```1P``````````````\)\!```````!!```2```````````````^)\!````
M```!!```30``````````````:)T!```````"!````P``````````````<)T!
M```````"!```!```````````````>)T!```````"!```!0``````````````
M@)T!```````"!```!@``````````````B)T!```````"!```!P``````````
M````D)T!```````"!```"```````````````F)T!```````"!```"@``````
M````````H)T!```````"!```"P``````````````J)T!```````"!```#```
M````````````L)T!```````"!```#0``````````````N)T!```````"!```
M#@``````````````P)T!```````"!```#P``````````````R)T!```````"
M!```$@``````````````T)T!```````"!```$P``````````````V)T!````
M```"!```%```````````````X)T!```````"!```%0``````````````Z)T!
M```````"!```%@``````````````\)T!```````"!```%P``````````````
M^)T!```````"!```&````````````````)X!```````"!```&@``````````
M````")X!```````"!```&P``````````````$)X!```````"!```'0``````
M````````&)X!```````"!```'@``````````````()X!```````"!```'P``
M````````````*)X!```````"!```(```````````````,)X!```````"!```
M(0``````````````.)X!```````"!```(@``````````````0)X!```````"
M!```(P``````````````2)X!```````"!```)```````````````4)X!````
M```"!```)0``````````````6)X!```````"!```)@``````````````8)X!
M```````"!```)P``````````````:)X!```````"!```*```````````````
M<)X!```````"!```*0``````````````>)X!```````"!```*@``````````
M````@)X!```````"!```*P``````````````B)X!```````"!```+@``````
M````````D)X!```````"!```+P``````````````F)X!```````"!```,0``
M````````````H)X!```````"!```,@``````````````J)X!```````"!```
M,P``````````````L)X!```````"!```-```````````````N)X!```````"
M!```-0``````````````P)X!```````"!```-@``````````````R)X!````
M```"!```-P``````````````T)X!```````"!```.```````````````V)X!
M```````"!```.0``````````````X)X!```````"!```.P``````````````
MZ)X!```````"!```/```````````````\)X!```````"!```/0``````````
M````^)X!```````"!```/@```````````````)\!```````"!```/P``````
M````````")\!```````"!```0```````````````$)\!```````"!```00``
M````````````&)\!```````"!```0@``````````````()\!```````"!```
M1```````````````*)\!```````"!```10``````````````,)\!```````"
M!```20``````````````.)\!```````"!```2@``````````````0)\!````
M```"!```2P``````````````2)\!```````"!```3```````````````4)\!
M```````"!```3@``````````````6)\!```````"!```3P``````````````
M8)\!```````"!```4```````````````_7N_J?T#`)&N`0"4_7O!J,`#7]8`
M``````````````#P>[^IT```D!&R1OD0@C61(`(?UA\@`]4?(`/5'R`#U=``
M`)`1MD;Y$*(UD2`"'];0``"0$;I&^1#"-9$@`A_6T```D!&^1OD0XC61(`(?
MUM```)`1PD;Y$`(VD2`"'];0``"0$<9&^1`B-I$@`A_6T```D!'*1OD00C:1
M(`(?UM```)`1SD;Y$&(VD2`"'];0``"0$=)&^1""-I$@`A_6T```D!'61OD0
MHC:1(`(?UM```)`1VD;Y$,(VD2`"'];0``"0$=Y&^1#B-I$@`A_6T```D!'B
M1OD0`C>1(`(?UM```)`1YD;Y$"(WD2`"'];0``"0$>I&^1!"-Y$@`A_6T```
MD!'N1OD08C>1(`(?UM```)`1\D;Y$((WD2`"'];0``"0$?9&^1"B-Y$@`A_6
MT```D!'Z1OD0PC>1(`(?UM```)`1_D;Y$.(WD2`"'];0``"0$0)'^1`".)$@
M`A_6T```D!$&1_D0(CB1(`(?UM```)`1"D?Y$$(XD2`"'];0``"0$0Y'^1!B
M.)$@`A_6T```D!$21_D0@CB1(`(?UM```)`1%D?Y$*(XD2`"'];0``"0$1I'
M^1#".)$@`A_6T```D!$>1_D0XCB1(`(?UM```)`1(D?Y$`(YD2`"'];0``"0
M$29'^1`B.9$@`A_6T```D!$J1_D00CF1(`(?UM```)`1+D?Y$&(YD2`"'];0
M``"0$3)'^1"".9$@`A_6T```D!$V1_D0HCF1(`(?UM```)`1.D?Y$,(YD2`"
M']:P``#P$3Y'^1#B.9$@`A_6L```\!%"1_D0`CJ1(`(?UK```/`11D?Y$"(Z
MD2`"']:P``#P$4I'^1!".I$@`A_6L```\!%.1_D08CJ1(`(?UK```/`14D?Y
M$((ZD2`"']:P``#P$59'^1"B.I$@`A_6L```\!%:1_D0PCJ1(`(?UK```/`1
M7D?Y$.(ZD2`"']:P``#P$6)'^1`".Y$@`A_6L```\!%F1_D0(CN1(`(?UK``
M`/`1:D?Y$$([D2`"']:P``#P$6Y'^1!B.Y$@`A_6L```\!%R1_D0@CN1(`(?
MUK```/`1=D?Y$*([D2`"']:P``#P$7I'^1#".Y$@`A_6L```\!%^1_D0XCN1
M(`(?UK```/`1@D?Y$`(\D2`"']:P``#P$89'^1`B/)$@`A_6L```\!&*1_D0
M0CR1(`(?UK```/`1CD?Y$&(\D2`"']:P``#P$9)'^1""/)$@`A_6L```\!&6
M1_D0HCR1(`(?UK```/`1FD?Y$,(\D2`"']:P``#P$9Y'^1#B/)$@`A_6L```
M\!&B1_D0`CV1(`(?UK```/`1ID?Y$"(]D2`"']:P``#P$:I'^1!"/9$@`A_6
ML```\!&N1_D08CV1(`(?UK```/`1LD?Y$((]D2`"'];]>[FI_0,`D?-3`:FT
M``#P]5L"J;,``/#W&P#Y@]I'^:*'!*FA0P&1H%\`N:(C`9&@<P&19`!`^:0W
M`/D$`(#2B/__EZ(``/"@``#P0NA'^0#P1_GA`P*JC`P`E*```/``T$?Y``!`
M.6`!`#5-__^7P@``L$!P`/D@#@"TLP``\!C__Y=@SD?Y``!`N5'__Y<?U",Y
M<\Y'^6`"0+E-__^7`<A3.2$`'S(!R!,Y8`)`N4C__Y<"R%,YH5]`N0,`_))"
M```R(10`$0+($SDA?$"3/P`#ZV@)`%0@\'W3TP``L#C__Y>D*T#YQ@``D&4"
M!Y&B7T"Y`P``\`$``/#'6$#YB`"`4H8`0/EC@".1(:`CD5\$`'$&#`"I!P0!
MJ:B`$+B@`!'XC0<`5(0@`)%#$``1H0"`4N<`@)+ES"&+AH1`^"$$`!$_``-K
M!F@E^&'__U1V`@>1!<PCBP$``+#C`P"J0@P`$2%@-Y'``E+X!`"`TK^`'_AO
M__^7]0,`*B`#`#1V`@>1MY,!D<`"4OCM_O^7````\.$#%ZH``!F1U00`E(`"
M`+1S`@>18`)2^-'^_Y=4__^7E-I'^>`#%2JB-T#Y@0)`^4$``<KA`P"U\U-!
MJ?5;0JGW&T#Y_7O'J,`#7];``E+X<___E_4#`"KE__\7P()1^$`!`+0"#`"4
MZO__%Z$``/````#P`&`CD2'@1_DL__^70P`("\[__Q<```#PX0,7J@`@%Y&R
M!`"4P((1^*#[_[3S"P"4V___%R``@%*$_O^7[_[_EQT`@-(>`(#2Y0,`JN$#
M0/GB(P"1Y@,`D:```/``[$?YHP``\&/D1_FD``#PA+A'^;[^_Y?Q_O^7H```
M\`#41_E```"TZ?[_%\`#7]8`````P0``D,```)`AX`*1`.`"D2$<`)$A``#+
M/S@`\:D``%2A``#P(;Q'^4$``+0@`!_6P`-?UA\@`]7!``"0P```D"'@`I$`
MX`*1(0``RR'\0Y,A_$&+(?Q!D\$``+2B``#P0OQ'^6(``+1``!_6'R`#U<`#
M7]8?(`/5_7N^J?T#`)'S"P#YTP``D&#B0CE``0`UH```\`#`1_F```"TP```
MD``$0/E1_O^7UO__ER``@%)@X@(Y\PM`^?U[PJC``U_6H```\`#@*Y$!`$#Y
M80``M=K__Q<?(`/5H0``\"'X1_F!__^T_7N_J?T#`)$@`#_6_7O!J-'__Q?_
M0PK1J```\`3@`)$)X`&1_7N_J?T#`)$!V4?YHF,`D4<@`)$C`$#YHT\!^0,`
M@-*!`$"Y@X1`^"$(P%KA@!_XGP`)ZV'\8--E_&C3)MQXTZ4<>)(A'&C3QAQP
MDB$`!JJCX$.J(0`#JN$$`?@A_O]41@`(D40`0/E"(`"10P1`^44<0/E!,$#Y
M8P`$RM\``NLA``7*(0`#RB/\7]-A!`&J(7Q`DD$\`/EA_O]4!R1`J2$SC](*
M+$&I(`%GGD(!9YZB#T#Y80%GGD%0J_)#``&+XOQ;TPP00/E"%`>JL!M`^1`"
M`8M`'&$N!`!FGN``9YZ"0"*+)/U"TT(``XNC$T#YA'@)JD(`#(N.?$"290`!
MB\$!9YY&?$"2Q/Q;TX04!JH@'&(N`P!FGF,`"XMC``6+9$`DB^/\0M.-?$"2
M8W@'JF]\0)*C%T#Y0@`/BF4``8O#`2:*8P`"JL+\0M-C``J+8P`%BZ7]6]-"
M>`:JY@$MBJ44#:I"?$"2A``"BF-`)8O$``2J97Q`DH0`#HN$`!"+IOQ;T\84
M!:J$0":+IOU"T\UX#:J&?$"2K7U`DFX`#8JC'T#Y<``!BT,`)8IC``ZJSOQ;
MTV,`#XO.%0:J8P`0B[`C0/EC0"Z+KOQ"TQ`"`8O%>06JK@$FBJ5\0)*/``6*
M9'Q`DLX!#ZK"`0*+COQ;TT(`$(O.%02J0D`NB\[\0M-0?$"2QGD&JL9\0))N
M``:*HR=`^6\``8NC`"2*8P`.JF,`#8L-_EO38P`/BZT5$*IC0"V+C?Q"TV]\
M0)*D>02JA'Q`DDT`!(JB*T#Y3@`!B\(`,(I"``VJ[?U;TT(`!8L%_D+3K14/
MJD(`#HNE>!"JI7Q`DD)`+8MM``6*HR]`^4Y\0))P``&+@P`OBF,`#:IC``:+
MS?U;T^;]0M-C`!"+K14.JL9X#ZK&?$"28T`MBTT`!HJB,T#Y;WQ`DE```8NB
M`"Z*0@`-JD(`!(OM_5O3Q/U"TT(`$(NM%0^JA'@.JH1\0))"0"V+;0`$BJ,W
M0/E.?$"2<``!B\,`+XIC``VJ8P`%B\W]6]/E_4+38P`0BZT5#JJE>`^JI7Q`
MDF-`+8M-``6*HCM`^6]\0))0``&+@@`NBD(`#:I"``:+[?U;T\;]0M-"`!"+
MK14/JL9X#JK&?$"20D`MBVT`!HJC/T#Y3GQ`DG```8NC`"^*8P`-JF,`!(O-
M_5O3Y/U"TV,`$(NM%0ZJA'@/JH1\0))C0"V+30`$BJ)#0/EO?$"24``!B\(`
M+HI"``VJ0@`%B^W]6]/%_4+30@`0BZT5#ZJE>`ZJI7Q`DD)`+8MM``6*HT=`
M^4Y\0))P``&+@P`OBF,`#:IC``:+QOU;TV,`$(O&%`ZJ8T`FB^;]0M-M?$"2
MSW@/JN]]0))0``^*HDM`^48``8NB`"Z*0@`0JD(`!(ND_5O30@`&B\;]0M.$
M%`VJQG@.JLY\0))"0"2+9@`.BJ-/0/E$?$"2<``!B^,!+8IC``:J8P`%BX7\
M6]-C`!"+I10$JF-`)8NE_4+3K7@-JJ530/FM?4"21@`-BF)\0)*P``&+Q0$D
MBJ4`!JI&_%O3I0`/BZ4`$(O&%`*JI4`FBX;\0M.O?$"2Q'@$JJ970/F$?$"2
MT``!BV,`!(JF`2**Q@`#JN/]6]/&``Z+8Q0/JL8`$(O00".+0_Q"TPY^0))B
M>`*JHUM`^49\0)*E``:*8P`!BX$`+XHA``6JQ?U;TR$`#8LA``.+X_U"TZ44
M#JIC>`^JS_U"TS%`)8M"``/*0@`02C!^0))"``2+(72=TJ1?0/DAVZWR!?Y;
MT^]Y#JJ$``&+0@`$BZ44$*JD8T#Y14`EBP+^0M.N?$"2C0`!BV0`#\I">!"J
MA``12H0`!HO&_5O3A``-B\84#JJ&0":+Y`$"RLU\0)*$``5*A$`CBZ-G0/FE
M_5O38P`!BX0``XNE%`VJP_U"TX5`)8ND:T#Y;G@.JK!\0))#``[*A``!BV,`
M!DH&_EO38T`OBV,`!(ND_4+3QA00JH1X#:IF0":+PP$$RLU\0))C``5*8T`B
MBZ)O0/FE_5O30@`!BV,``HNE%`VJ94`EBP/^0M.O?$"28W@0JH(``\I"``9*
MIG-`^4)`+HO&``&+0@`&B^;]6]/&%`^J1D`FBZ+]0M-">`VJS7Q`DFX``LK%
M`05*I$`DBZ5W0/FE``&+A``%BZ7]6].E%`VJA4`EB^3]0M.N?$"2A'@/JD\`
M!,KF`09*PT`CBZ9[0/G&``&+8P`&B\;]6]/&%`ZJ9D`FBZ/]0M-C>`VJS7Q`
MDH\``\KE`05*HD`BBZ5_0/FE``&+0@`%BZ7]6].E%`VJ14`EB\+]0M-">`ZJ
MKGQ`DF\``LKF`09*Q$`DBZ:#0/G&``&+A``&B\;]6]/&%`ZJAD`FBZ3]0M.$
M>`VJS7Q`DD\`!,KE`05*HT`CBZ6'0/FE``&+8P`%BZ7]6].E%`VJ94`EB\/]
M0M.O?$"28W@.JHX``\K&`09*PD`BBZ:+0/G&``&+0@`&B^;]6]/&%`^J1D`F
MBZ+]0M/.?$"20G@-JFT``LJE`05*I$`DBZ6/0/FE``&+A``%B\7]6].E%`ZJ
MA4`EB^3]0M.M?$"2A'@/JD\`!,KF`09*PT`CBZ:30/G&``&+8P`&BZ;]6]/&
M%`VJ9D`FB\/]0M-C>`ZJSGQ`DH\``\KE`05*HD`BBZ670/FE``&+0@`%B\7]
M6].E%`ZJ14`EBZ+]0M.P?$"20G@-JFT``LJF`09*#?Y;T\1`)(NFFT#YK140
MJL8``8N$``:+C4`MB\3]0M.O?4"2A'@.JD8`!,K%``5*HT`CBZ6?0/FE``&+
M8P`%B^7]6].E%`^J8T`EBP7^0M-F?$"2L'@0JH4`$,JM``U*I:-`^<[\6].E
M``&+HD$BBT(`!8O.%0:J3D`NB^+]0M/%?4"20G@/J@T"`LJC`0-*K?Q;TV1`
M)(NCIT#YK14%JF,``8N$``.+P_Q"TV9X!JJ$0"V+0P`&RH]\0)*MJT#Y8P`.
M2J$!`8MC0#"+80`!B^/]6].MKT#Y8Q0/JC!`(XNA_$+3`WY`DB5X!:K!``6J
M(0`$BL0`!8HA``0JY/U"TR)`(HN!FY?28>.Q\H1X#ZJM`0&+KP`$BD(`#8MM
M_%O3K14#JDY`+8NM``2JK0$0BL)]0)*M`0\JID$FBZVS0/FM`0&+Q@`-BTW\
M6].M%0*JST`MBV;\0M/#>`.JYGU`DHT``ZJM`0Z*C@`#BJT!#BJE026+K;=`
M^:T!`8NE``V+S?Q;TZT5!JJN0"V+1?Q"TZ)X`JK%?4"2;0`"JJT!#XIO``**
MK0$/*J1!)(NMNT#YK0$!BX0`#8NM_%O3K14%JH]`+8O$_$+3AG@&JN1]0))-
M``:JK0$.BDX`!HJM`0XJHT$CBZV_0/FM`0&+8P`-BXW\6].M%02J;D`MBZ/\
M0M-E>`6JPWU`DLT`!:JM`0^*SP`%BJT!#RJB02*+K<-`^:T!`8M"``V+;?Q;
MTZT5`ZI/0"V+@OQ"TT1X!*KB?4"2K0`$JJT!#HJN``2*K0$.*J9!)HNMQT#Y
MK0$!B\8`#8M-_%O3K14"JLY`+8MF_$+3PW@#JL9]0)*-``.JK0$/BH\``XJM
M`0\JI4$EBZW+0/FM`0&+I0`-B\W\6].M%0:JKT`MBT7\0M.B>`*JY7U`DFT`
M`JJM`0Z*;@`"BJT!#BJD022+K<]`^:T!`8N$``V+K?Q;TZT5!:J.0"V+Q/Q"
MTX9X!JK$?4"230`&JJT!#XI/``:*K0$/*J-!(XNMTT#YK0$!BV,`#8N-_%O3
MK14$JF]`+8NC_$+397@%JN-]0)+-``6JK0$.BLX`!8JM`0XJHD$BBZW70/FM
M`0&+0@`-BVW\6].M%0.J3D`MBX+\0M-$>`2JPGU`DJT`!*JM`0^*KP`$BJT!
M#RJF02:+K=M`^:T!`8O&``V+3?Q;TZT5`JK/0"V+9OQ"T\-X`ZKF?4"2C0`#
MJJT!#HJ.``.*K0$.*J5!)8NMWT#YK0$!BZ4`#8O-_%O3K14&JJY`+8M%_$+3
MHG@"JL5]0))M``*JK0$/BF\``HJM`0\JI$$DBZWC0/FM`0&+A``-BZW\6].M
M%06JCT`MB\3\0M.&>`:JY'U`DDT`!JJM`0Z*3@`&BJT!#BJC02.+K>=`^:T!
M`8MC``V+C?Q;TZT5!*IN0"V+H_Q"TV5X!:K#?4"2S0`%JJT!#XK/``6*K0$/
M*J)!(HNMZT#YK0$!BT(`#8MM_%O3K14#JD]`+8N"_$+31'@$JN)]0)*M``2J
MK0$.BJX`!(JM`0XJID$FBZWO0/FM`0&+Q@`-BTW\6].M%0*JSD`MBV;\0M/-
M?4"2PW@#JH8``ZK&``^*CP`#BL8`#RK%0"6+IO-`^<8``8NE``:+IOU;T\84
M#:JP0":+1?Q"TP9^0)*B>`*J90`"JJ4`#HIN``**I0`.*J1`)(NE]T#YI0`!
MBX0`!8O%_%O3I10&JH]`)8ND_4+3[GU`DH1X#:I%``2J30`$BJ4`$(JE``TJ
MHT`CBZ7[0/D(V4?YH0`!B\7]6]-A``&+P_Q"TZ44#JIC>`:JIO]`^25`)8N!
M``/*(0`/2JU\0)(B0"*+P3J8TD%,N?+&``&+0@`&BZ;]6]/&%`VJ1D`FB\+]
M0M//?$"23G@.JF(`#LI"``5*Y?U;TT)`)(ND`T'YI10/JH0``8M"``2+I/U"
MTX1X#:I%0"6+P@$$RJU\0))"``9*0T`CBZ('0?FF_5O30@`!BV,``HO&%`VJ
M9D`FB^/]0M-C>`^JSWQ`DH(``\I"``5*I0M!^4)`+HNE``&+0@`%B^7]6].E
M%`^J14`EBZ+]0M-">`VJK7Q`DFX``LK&`09*Q$`DBZ8/0?G&``&+A``&BZ;]
M6]/&%`VJAD`FB^3]0M/.?$"2A'@/JD\`!,KE`05*HT`CBZ430?FE``&+8P`%
MB\7]6].E%`ZJ94`EBZ/]0M-C>`VJK7Q`DH\``\KF`09*PD`BBZ870?G&``&+
M0@`&BZ;]6]/&%`VJ1D`FB\+]0M-">`ZJSGQ`DF\``LKE`05*I$`DBZ4;0?FE
M``&+A``%B\7]6].E%`ZJA4`EBZ3]0M.$>`VJK7Q`DD\`!,KF`09*PT`CBZ8?
M0?G&``&+8P`&BZ;]6]/&%`VJ9D`FB\/]0M-C>`ZJSGQ`DH\``\KE`05*HD`B
MBZ4C0?FE``&+0@`%B\7]6].E%`ZJ14`EBZ+]0M-">`VJK7Q`DF\``LKF`09*
MQ$`DBZ8G0?G&``&+A``&BZ;]6]/&%`VJAD`FB\3]0M.$>`ZJSGQ`DD\`!,KE
M`05*HT`CBZ4K0?FE``&+8P`%B\7]6].E%`ZJ94`EBZ/]0M-C>`VJK7Q`DH\`
M`\KF`09*PD`BBZ8O0?G&``&+0@`&BZ;]6]/&%`VJ1D`FB\+]0M/0?$"20G@.
MJFX``LK%`05*I$`DBZ4S0?FE``&+A``%BP7^6].E%!"JA4`EBZ3]0M.O?$"2
MA'@-JDT`!,JF`09*[OU;T\-`(XNF-T'YSA4/JL8``8MC``:+!OY"TVY`+HO&
M>!"JS7U`DH,`!LIE``5*HSM!^:)`(HNE_5O38P`!BT(``XNE%`VJ14`EB^+]
M0M.C?$"20G@/JL\``LKN`0Y*Q$$DBZX_0?G.`0&+A``.BV[\6]/.%0.JD$`N
MBZ3]0M.->`VJ!'Y`DDX`#<K%`05*ID`FBZ5#0?FE``&+Q@`%BX7\6].E%`2J
MST`EBV7\0M/F?4"2HW@#JJ4!`\IL``P+I0`02J)`(HNE1T'YI0`!BT4`!8O"
M_%O30A0&JD(`!0N%_$+3*0$""Z1X!*H)!`#Y8P`$RH0`"PMC``]*!+`!J:1+
M0?E%_%O38T`MBX$``8MC``&+H10"JB$``PLG``<+!P``^:%/0?D"`4#Y(@`"
MRL'\0M,A>`:J*@`*"PH(`/F"``"U_7O!J/]#"I'``U_61?K_E_U[O*G]`P"1
M\U,!J?5;`JGW8P.I@`8`M*(``-!"]$?Y6`!`^1@&`+0"`$`Y%0"`4E_T`'%$
M&$!Z`0,`5!,#0/GS`0"T]P,!JO8#`*JU?D"3]`,8JN`#$ZKB`Q6JX0,6J@3Z
M_Y>````U8&IU.!_T`'%``@!4DXY`^//^_[7@`Q.J\U-!J?5;0JGW8T.I_7O$
MJ,`#7]8?(`/5]0,`JJ(>0#A?]`!Q1!A`>J'__U2U`@!+X___%Q\@`]6``AC+
MM08`D7,"%8L`_$.3X`(`N>`#$ZKS4T&I]5M"J?=C0ZG]>\2HP`-?UA,`@-+E
M__\7'R`#U?U[O*G]`P"1]5L"J;8``-#S4P&ILP``T/4#`*JTTP"1P-I'^7/V
M1_D!`$#YH1\`^0$`@-+A`Q2JX`,5JK7__Y?@`0"THS>`N6("0/E`#`.+`01`
M^4%X(_CA_O^T`"``D0$$0/D!``#YH?__M>$#%*K@`Q6JI___EV#^_[76VD?Y
MH1]`^<`"0/D@``#*H```M?-30:GU6T*I_7O$J,`#7];@^?^7'R`#U?U[N:G]
M`P"1\U,!J?,#`:KU6P*IM0``T/=C`ZGT`P"J^6L$J?LK`/F@VD?Y(0!`.3_T
M`'$!`$#YH3<`^0$`@-)S%I.:X`,3JECY_Y?W`P"JH9,!D>`#%*J$__^7(`@`
MM/8#`*I1^?^7_P(`Z^D&`%2V9X"YN0``T-;R?=.``D`Y'_0`<0080'H@#`!4
MX0,4JB`<0#@?]`!Q!!A`>J'__U0A`!3+(7Q`DSGW1_G@"@"1```!BS<#0/EX
M^?^7X&HV^``+`+2C9X"Y@`8`D2(#0/F!`D`Y/_0`<4)X8_@D&$!Z00``.<``
M`%0!%$`X/_0`<4$<`#@D&$!Z@?__5*`'@%)!!`"10```.6`60#@@%``XP/__
M-0``@%*UVD?YHC=`^:$"0/E!``'*`0@`M?-30:GU6T*I]V-#J?EK1*G[*T#Y
M_7O'J,`#7]8``(#286I@.,%J(#@`!`"1H?__->[__Q>Y``#0(/='^18`0/G`
M`D#Y(`4`M.$#%JH``(!2`@``%.`#&"HBC$#X&`0`$:+__[4`#``1`'Q]DZ$`
M`/`BP$"YP@$`-.$#`*K@`Q:J:_G_ER'W1_D@``#Y0`,`M!M_0)/Z`P"J=O-]
MTWL'`)%?>SOXN&<`N:K__Q<B`(!2(L``N2[Y_Y?Z`P"JP`$`M!M_0)/A`Q:J
M=O-]T^(#%JKC^/^7(/='^1H``/GP__\7`0"`TJ;__Q<``H#2&`"`4M___Q<`
M`(`2O?__%U3Y_Y<?(`/5_7NRJ?T#`)'U6P*IM0``T/-3`:GW8P.I^6L$J:':
M1_DB`$#YHF\`^0(`@-*```"T`0!`.?8#`*J!`0`UM=I'^:%O0/F@`D#Y(```
MRD`)`+7S4T&I]5M"J?=C0ZGY:T2I_7O.J,`#7];@^/^7]P,`JF#^_[08``#0
MN6,!D1AC%9'4!8!2X`,7JG3Y_Y?S`P"JX`$`M&%.0#F!`@%K(0(`5&!20#D`
M__\T@`(`:^`#`$M!``!48%9`.6`!`#7@`Q>J9OG_E_,#`*I@_O^UX`,7JAKY
M_Y?@`Q:J1/G_E]C__Q<A_?\TX`,6JG-.`)&C^/^7^@,`JN`#$ZJ@^/^7```:
M"P`(`!$`?$"3V/C_E_H#`*KE`Q.JY`,6JN,#&*H"`("2(0"`4IGX_Y?B`QFJ
MX0,:J@``@%*=^/^7'P0`,:```%2@:T"Y``P4$A\00''@``!4X`,:JG7Y_Y?@
M`QJJ-_G_E\G__Q<?(`/5X`,:JJ7__Y?Z__\7]?C_E_U[OJG]`P"1\U,!J;,`
M`-#T`P"J<\Y'^6`"0+GA^/^7`N`'D>$#%*H``(!2(?G_E\```#0``(!2\U-!
MJ?U[PJC``U_6'R`#U6`"0+G5^/^7``A"N0`,%!(?$$!QX```5&`"0+G/^/^7
M``A"N0`,%!(?*$!Q`?[_5.`#%*I!`(!2Z/C_EQ\``''@%Y\:\U-!J?U[PJC`
M`U_6_P=`T0(``-#_0P#1_7N\J?T#`)'S4P&IM```T/5;`JFU(P&1]QL`^?8#
M`*J#VD?Y0(`5D?<#`:KA`Q6J9`!`^:0G"/D$`(#2XO^!TE?X_Y<?``!Q#00`
M5`,$`%&ARF,X@0,`-.,#`"IS?$"3X`,5JN(#$ZKA!8!2$/G_E\`"`+2@``#0
M`,Q'^0``0+F?^/^7XP,3JN(#%:KA`Q:J#_G_EY3:1_FA)TCY@`)`^2```,H@
M`@"U\U-!J?5;0JGW&T#Y_7O$J/\'0)'_0P"1P`-?UL/\_S6@``#0`,Q'^0``
M0+F*^/^7X@,7JN$#%JIG^/^7[/__%Y'X_Y>@``#0_7N_J?T#`)$`S$?Y``!`
MN7_X_Y>B``#0`P``T`$``-!C@!21_7O!J"'`%9%"R$?YM_C_%_U[OJG]`P"1
M\PL`^;,``-!SSD?Y8`)`N7#X_Y?K__^78`)`N6WX_Y?S"T#Y!```T`(``-"$
M0".1`0``T/U[PJCC`P2J0@`!D2%`%I$%`(!2OOC_%Q\@`]7_"T#1_X,`T?U[
MO:G]`P"1\U,!J;0``-#U6P*IL^,`D8#:1_D!`$#YH2<0^0$`@-(D^/^7Y`,`
M*@4``-`#``#0I:`6D6/`%I'@`Q.J(@""TB$`@%+G]_^7``3X-P`(@M("`(+2
MM@,`B^`#$ZKA`Q:J[/?_E_,#`*H``_@W``0`$0!\0),3^/^7]0,`JL```+1S
M?D"3X0,6JN(#$ZK%]_^7OVHS.)3:1_G@`Q6JHB=0^8$"0/E!``'*00$`M?-3
M0:GU6T*I_7O#J/\+0)'_@P"1P`-?UA\@`]45`(#2\O__%S3X_Y<?(`/5QO__
M%Q\@`]7_!T#1`@``T/]#`-']>[JI_0,`D?=C`ZFW``#0\U,!J?0#`*KU6P*I
M0"`7D?EK!*GS`P&J^RL`^:&3`9'BVD?Y0P!`^:,W"/D#`(#2V?W_E_4#`*K@
M`Q2JX06`4FWX_Y>``@"T````T.$#%*H`8!>1-O[_E^`#%*KWVD?YHC=(^>$"
M0/E!``'*P0P`M?-30:GU6T*I]V-#J?EK1*G[*T#Y_7O&J/\'0)'_0P"1P`-?
MUN`#%*H6``#0UJ(7D8WW_Y?Z`P`JX0,6JN`#$ZJ%]_^7\P,`JH#\_[1@`D`Y
M&0``T!@``+`YPQ>1&.,7D<`&`#2U``"TX0,3JN`#%:H1^/^70`4`-.`#$ZIZ
M]_^7X0,`*F#"((L`\%\X'[P`<>$``%0A!`!18,(ABW_*(3@`\%\X'[P`<6#_
M_U1`!P`1`0`!"S_\/W$,^?]4NZ,!D>0#$ZKF`Q2JY0,9JN,#&*K@`QNJLP``
ML`(`@M(A`(!29??_EW/.1_E@`D"YQO?_EP+@!Y'A`QNJ``"`4F;W_Y?@```U
M8`)`N;_W_Y<`"$*Y``P4$A\@0'&``@!4X0,6J@``@-),]_^7\P,`JF#U_[1@
M`D`Y@/G_-1,``+`5`0"T<P(7D>`#%:KA`Q.JVO?_ER$`@%)`_O\TU?__%R$`
M@%)S`A>1TO__%^`#&ZHA`(!2Q??_ET#]_S4```"PX0,;J@!@%Y'._?^7X`,;
MJE[W_Y>7__\7J/?_EQ\@`]4!`$`YP0``-`($`)$_O`!Q`!""FD$40#BA__\U
MP`-?UOU[OJG]`P"1\U,!J6`#`+04`$`Y\P,`JA0#`#0C]_^7``0`T6("`(M_
M`@+K8@0`5&!J8#@?O`!QH```5!P``!1``$`Y'[P`<2$#`%1"!`#1?P("ZV'_
M_U2?O@!QX```5/-30:D```"P_7O"J`#`%Y$V]_\7'R`#U4``@-)']_^70`4`
MM`(``+!"`!>10@!`>0(``'GS4T&I_7O"J,`#7]9``$`Y'[P`<8`!`%1"!`#1
M?P("ZV/__U1_`@+KX/S_5$($`-%_`@+KX@``5$``0#D?O`!Q@0``5$($`-%_
M`@+K8___5$(`$\M`"`"1'P1`\<@!`%2@``#0X0,3J@```Y%"!`"1$R``D0,`
M@M+@`Q.J)O?_E^`#$ZKS4T&I_7O"J,`#7]8?(`/5``"`TO-30:G]>\*HP`-?
MUOU[N*D!``"P(8`4D0```+#]`P"1\U,!J;,``+#U6P*I```8D?=C`ZD6``"P
M8]I'^1<``+`F'$&I8@!`^:(_`/D"`(#2)!1"J:8?!:DA8$!Y&```L*07!JD4
M``"PH>,`>92"&9&U,P&1+OW_EP```+``0!B1*_W_EP```+``8!B1*/W_EP``
M`+``H!B1)?W_E\#"&)$C_?^7````L```&9$@_?^7X"(7D1[]_Y<`0QF1'/W_
ME^`#%*H:_?^7````L`#`&9$7_?^7````L`!@%Y$4_?^7````L```&I$1_?^7
M````L`!`&I$._?^7````L.$#%:H`@!J1SOS_EX```+3A`P"JX`,4JC#]_Y<`
M``"PX0,5J@#@&I'&_/^7H```M`(``+#A`P"J0$`;D2?]_Y<```"PX0,5J@"`
M&Y&]_/^70`(`M.$#`*K@(A>1'_W_EP$``+#`PAB1(6`<D1O]_Y=SVD?YH3]`
M^6`"0/D@``#*8`,`M?-30:GU6T*I]V-#J?U[R*C``U_6````L.$#%:H`P!N1
MI_S_E\```+3A`P"J`$,9D0G]_Y?J__\7'R`#U0$``+"@AP&1(2`<D4(!@-*T
M0P&1M_;_ET#\_S6!;@"1`$,9D?W\_Y?>__\7V?;_E_U[O:G]`P"1\U,!J;,`
M`+"T``#08=I'^8`20+DB`$#YHA<`^0(`@-(?!``Q(`$`5'/:1_FB%T#Y80)`
M^4$``<JA`@"U\U-!J?U[PZC``U_6````L*&3`)$`0!F1??S_ET`!`+0!`$`Y
M/\``<>`'GQH_``!QX0>?&@```0J`$@"Y[/__%Q\@`]4``(!2@!(`N>C__Q>S
M]O^7_7N_J?T#`)%4]O^7T_;_EX```+0``$#Y_7O!J,`#7]8``(#2_?__%_U[
MM:FA``#0(4``D?T#`)'W8P.IN```L/5;`JGV`P"J("``D?-3`:GY:P2I!=M'
M^?LK`/D"#$&I!AQ"J:(/"*D$!$#Y"!A`^:``0/F@5P#Y``"`TB$$0/FF'PFI
MH1,'J:A3`/E!`P"T\P,!J@```+`!``"PM>,!D;>S`9$ZH!>1&>`7D08``!3A
M`Q:J]?;_EX`#`+2SAD#XLP$`M.$#%ZK@`Q.J._S_E_0#`*I@``"T`0!`.:'^
M_S7@`Q.JX0,6JIK\_Y>SAD#XL_[_M1C;1_FA5T#Y``-`^2```,J@`P"U\U-!
MJ?5;0JGW8T.I^6M$J?LK0/G]>\NHP`-?UA\@`]7@`Q:J\_7_E_L#`*K@`Q2J
M\/7_EV`#`(L`"`"1*?;_E_L#`*KF`Q2JY0,:JN0#%JKC`QFJ`@"`DB$`@%+I
M]?^7X0,;JN`#$ZIX_/^7TO__%U3V_Y<?(`/5_R-`T:$``-#_@P71(4``D2)@
M`9$C(`*1_7NZJ?T#`)'Y:P2IN4,"D?=C`ZFX``"P)!1$J?-3`:GU6P*I]@,`
MJOMS!:FT`P.1("A`^;.C`I$D%P"I!3>0T@3;1_FA`P6+(`L`^;4S`I&%`$#Y
M)0``^04`@-(:``"P0`1`J?]#`-&`!@"I0`1!J8`&`:E`!$*I@`8"J>$#%:I@
M"$#Y9!1`J6`*`/E`(Q>19!8`J>/[_Y>```"T`0!`.?<#`*KA(0`U</__EQ<`
M@-+\`P"J(`\`M.`#'*JI]?^7`/A_TP`$`)'B]?^7]P,`JH0#0#F$`0`T&P``
ML/,#%ZI[HQR1X`,3JN,#&ZH"`("2(0"`4G,*`)&>]?^7A!]`."3__S6@8T#Y
M0`(`M)0B`)$$```4'R`#U8"&0/B@`0"TX0,5JK_[_Y?S`P"J8/__M`$`0#DA
M__\T"OW_E^#^_S3@`Q.JK_7_E_,#`*J@`0"U%`"`4C/;=/@S`0"T8`)`.>``
M`#3@`Q.J_OS_EZ`*`#64!@`1,]MT^#/__[43`(#2X`,3JG?U_Y?[`P"JX`,7
MJG3U_Y<;`!L+>Q,0$7M_0)/@`QNJJ_7_E_0#`*H!``"P!@``L`,``+`EP!>1
MYP,7JL;`')'D`Q.J8^`<D0(`@)(A`(!29_7_E^`#%*H!.(!24/;_EQ\$`#&`
M!P!4LP``L'/.1_E@`D"YPO7_EP+@!Y'A`Q2J``"`4@+V_Y?W`P`J0`@`-*``
M`+`"``"PPP)`^>0#%*I"0!^1(0"`4@#$1_D3`(#2``!`^=KU_Y<8VT?Y`3>0
MTJ$#`8O@`Q.J(@!`^0$#0/E!``'*@3D`M;\#`)'S4T&I]5M"J?=C0ZGY:T2I
M^W-%J?U[QJC_(T"1_X,%D<`#7]8?(`/57O7_E_P#`*I`\?^U]R(`D>!J<_C`
M$@"TX0,5JE_[_Y=@__^T`0!`.<'^_S7W(@"1^/__%Q\@`]7@`Q.JE`8`$4[U
M_Y?S`P"J(/3_M*O__Q<*]O^7!0!`N;]$`'%`^/]4H```L`(``+##`D#YY`,4
MJD(@'9$A`(!2`,1'^1,`@-(``$#YI?7_E\O__Q<?(`/58`)`N7GU_Y<`"$*Y
M``P4$A\00'%!]_]48`)`N7/U_Y<<$$*Y(?7_EY\#`&N!]O]48`)`N6WU_Y<`
M"$*Y`"``$A\`!W'!]?]4X`,;JCOU_Y?S`P"J````L.$#%:H`0"61*OO_EZ`,
M`+35`D#Y'_7_E^$#`*K@`Q6J./W_E_4#`*K`"P"TX`,5JO#T_Y<?#`!Q^P,`
MJNT!`%0`?$"3`0``L``0`-$A(!Z1H`(`BWOU_Y<``0`U?Q,`<0`F`%1@$P!1
MH,(@BP#P7S@?O`!Q8"4`5'K^_Y?````UX`,5J@$`@%*R]?^7H'\`N<`(`#4!
M``"P````L"%@')$`0!F1`@``L!4``+!9P!>1M>(>D67[_Y?V`QFJ!?7_E^8#
M`"H'``"P`P``L.=`(Y%CH!Z1Y0,9JN0#%*K@`Q.J`@"`DB$`@%+[`P>JQ?3_
MEQ(``!0?(`/5IO7_EP``0+D?1`!Q00(`5/+T_Y?W!@`1Y@,`*N<#%RKE`Q:J
MY`,4JN,#%:K@`Q.J`@"`DB$`@%+[`P#YL_3_E^`#$ZH!.(!2G/7_EQ\$`#&`
M_?]4X`,4JECU_Y?A`Q.J0",7D3O[_Y?@`Q.J;_[_EUG__Q<?(`/5;/[_E^`#
M%ZK&]/^7\P,`JE/__Q>@`8#2'```L)R#')'4]/^7]P,`JF0*@%+S_O\7U0)`
M^:+__Q="`(!2(0*`DKOC!I'O]/^7H']`N>$#&ZK"`(#26_7_EZ#C1CF````U
MH.=&.1\,`7'`'0!4H']`N0(`@%(!`(#2M\,#D;RC!)'@]/^7O_\1J2%@A-(@
M<972H>BL\J#YO?+"GYO2OVL!N:$##ZG!CHK2`#Z<TD$&HO)`>KCR0A>S\J&#
M$*G@X@"1HH,`^:`[`/F@?T"YX0,;J@(`D-([]?^7'P``<>,#`*KV`P`JS0@`
M5**/0/E@?$"300P`"U\``>NBDT#Y20``5$($`)%`=$"+H8,1J:!K0;G`%``T
M`0B`4J,W`/DV``!+H3M`^7\`%FMVT)8:(,`@B^$#&ZK9?D"3X@,9JD7T_Y>@
M:T&YHS=`^<`"``L?``%QH&L!N:'[_U3@`Q>J=@`62WD#&8L?]O^7W_X`<<T"
M`%36`@%1P'X&4Q5D>M.U`@&1H&L`N34#%8LF'T"IX`,7JB070:F&'P"I(@]"
MJ807`:DH)T.I@@\"J8@G`ZDY`P&1#/;_E[\"&>N!_O]4H&M`N=8:`$N@.T#Y
MPGY`D^$#&:H#"8#27_3_E[9K`;F@?T"YX0,;J@(`D-+V]/^7'P``<>,#`*KV
M`P`JC/?_5*!_0+F8]/^7MM=1J>$/@!+`(D/3@<L@.``$`!$?X`!Q;`X`5`('
M@%+AX@"10@``2R#`((L!`(!20GQ`DV;T_Y>A_E#3HOY8T^`#%ZJUCP4YH8<%
M.<'^6-.U_DC3HH,%.:&3!3G"_E#3P?Y(T[6+!3FBEP4YO",&D;:?!3D;``"P
MH9L%.=CU_Y>E#T^I]0,<JJ7/!3FVQP61H@=0J:1\&%.F_%#3I?Q(TZ/?!3F7
MHP"1I<L%.67\6-.B[P4Y>Z,<D:73!3EE_%#38_Q(TZ"+0/FA_P4YH]L%.4/\
M6-.@#P8YH^,%.4/\4--"_$C3I,,%.:;'!3FBZP4Y(OQ8TZ77!3FB\P4Y(OQ0
MTR'\2-.CYP4YHO<%.0+\6-.A^P4Y`?Q0TP#\2-.B`P8YH0<&.:`+!CD"```4
MQ!9`..`#%:KC`QNJ`@"`DB$`@%*U"@"1TO/_E_\"%>L!__]4````L`<``+`#
M``"P!<`7D>=`(Y'F`QRJY`,4JF-@'I'@`Q.J`@"`DB$`@%*_PP8YP_/_E^`#
M%*IM]/^7X0,3JD`C%Y%0^O^7X`,3JH3]_Y=N_O\7^0,;JF___Q?6!D#YMMK_
MM.`#%JJQ\_^7'PP`\2G:_U0`$`#1`0``L"%`'I'``@"+/O3_EQ\``'&U$I::
MR?[_%P((@%+[X@"10@``2P$`@%)@PR"+0GQ`D_3S_Y?@`Q>J=O7_EW]_`*E_
M?P&I?W\"J?\V`/F(__\7H.M&.1\$`7$AXO]4H.]&.1\,`7'!X?]4H/-&.1\@
M`7%AX?]4H/=&.1\4`7$!X?]4M7]`N4(`@%(A!X"2X`,5*NCS_Y?A`QNJX`,5
M*B(%@-)4]/^7````D`<``)`#``"0!<`7D>=`(Y'F`QNJY`,4JF-@'I'@`Q.J
M`@"`DB$`@%)\\_^7SO[_%^KS_Y<?(`/5_7NXJ?T#`)'W8P.IN```D*#3`9'U
M6P*IH#<`^?4#`*J@``"0\U,!J1//1_GY:P2I^W,%J0#81_D!`$#YH3\`^0$`
M@-)@`D"YRO/_E_0#`*I@`D"YQ_/_EP+`0CD#``"0X0,5JF#`&)&"Q@(YB?G_
MEX```+0!`$`Y/\0`<>`2`%1X_/^7%L]'^;L``-#``D"YN//_EP$``)!C`8!2
M(:`@D2(`@%+'\_^78`8`M'4#!Y$!"$#YH()0N#<40/D?!`!QK04`5!F`@%(4
M`(!2,P"`4AD$H'(*```400A`^>`#&JK0\_^7X`,`-:""4+AS!@`1E`8`$1\`
M$VN-`P!4P`)`N9SS_Y>"?D"3X0,7J@,`@%+\\_^7_`,`JD`"`+0"`$#YHP)1
M^$`,0+EZV'/X```9"A\`$'$@_?]4P`)`N8WS_Y>!`T#Y0P"`4@(`@-)Y\_^7
MX0,`JN`#&JJR\_^78/S_-&`#!Y$`@%"X`00`43\`%&O`"P!4%,]'^8`"0+E]
M\_^7`0``D&,`@%(AP""1(@"`4HSS_Y?S`P"J@`$`M(`"0+ET\_^780I`^0(`
M`)!"X""1(0!`^4_S_Y=@"D#Y``!`^0`,0+G@#+`W%,]'^8`"0+EH\_^7`0``
MD&,`@%(A`"&1(@"`4G?S_Y?S`P"JH`$`M````)"A-T#Y`&`7D27Y_Y?U`P"J
M@`)`N=4)`+19\_^780I`^>(#%:HA`$#Y-?/_EQC/1_ET`P>1``-`N5'S_Y?S
M`P"J``-`N4[S_Y<!``"0(@"`4B$@(9&"\_^7X0,`J@(``)#@`Q.J0H`AD27S
M_Y<``T"Y0_/_EQ_$`CD"``"0H3=`^4`@%Y$&^?^7@((1^/,#`*K@!`"TX`,3
MJ@$X@%+`\_^7`00`$3\$`'$$B%%ZX08`5*```)`:V$?YH3]`^4`#0/D@``#*
M``8`M?-30:GU6T*I]V-#J?EK1*G[<T6I_7O(J,`#7]8`!$`Y0.W_-&C__Q<?
M(`/5'P0`<4WT_U05ST?Y=`,'D3,`@%*@`D"Y<P8`$1OS_Y?A`Q>JT?+_EX""
M4+@?`!-K+/__5);__Q>``E'XS?S_EX""$?CS`P"JP/K_M0```)``H"&12?/_
MEPSS_Y=@`P>18@I`^0$`4?A``$#Y(0!`^43Z_Y>Q__\7@`)`N0/S_Y=A"D#Y
M(0!`^53S_Y>5__\7"O/_EWL#!Y$!``"0XP,`*B!`(I'B`Q.J80-1^"$`0/DR
M\_^7'R`#U?U[OJG]`P"1\U,!J?0#`*I>^_^7`0!`.<$"`#0"!`"1\P,`JC^\
M`'%S$H*:011`.*'__S4;_/^7GP(`\0080'H@`0!4@`)`.>```#0!``"0X`,3
MJB'`')%:\_^7?P(`Z\```%3S4T&I_7O"J,`#7];S`P"J\/__%^`#%*KS4T&I
M_7O"J(WY_Q>C``"08]Q'^8,``+1C`$#YBO+_%Q\@`]4#`(#2A_+_%_U[O*G]
M`P"1]5L"J;4``)#S4P&IM```D+6B*Y&4PBN1E`(5R_=C`ZGV`P*J^`,`*O<#
M`:HY\O^7E/Y#DU0!`+03`(#2HWIS^.(#%JKA`Q>JX`,8*G,&`)%@`#_6GP(3
MZR'__U3S4T&I]5M"J?=C0ZG]>\2HP`-?UL`#7];]>[^I_0,`D?U[P:C``U_6
M``````$``@``````<&5R;'AS:2YC`````````%]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@```````````E<R\E<P```"]P<F]C+W-E;&8O97AE
M``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(``````$EN=&5R;F%L<SHZ
M4$%2.CI"3T]4`````&5X90``````+W!R;V,O)6DO)7,``````"X`````````
M4$%27U1%35```````````%!!4E]04D]'3D%-10`````Z`````````"\`````
M````)7,E<R5S``!015),-4Q)0@``````````4$523$Q)0@!015),-4]05```
M````````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`````
M`%!!4E]#3$5!3@````````!005)?1$5"54<`````````4$%27T-!0TA%````
M`````%!!4E]!4D=#``````````!005)?05)'5E\P````````4$%27T=,3T)!
M3%]$14)51P``````````4$%27T=,3T)!3%]435!$25(`````````4$%27U1-
M4$1)4@```````%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.````
M``````!005)?0TQ%04X]````````,0````````!365-414T``"4P,G@`````
M<&%R+0`````E<R5S)7,E<P``````````)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@```````'!A
M<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P``
M`"5S)7-T96UP+25U+25U)7,``````````"5S.B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y
M('EO=7(@;W!E<F%T:6]N*0H```````!!4D=6`````!@`````````<&5R;```
M```P`````````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#,U````56YA
M8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H``````````"5S````````+64````````M+0```````%53
M15(`````55-%4DY!344``````````%1-4$1)4@``5$5-4$1)4@!414U0````
M`%1-4```````+W1M<`````!,1%],24)205)97U!!5$@`3$E"4$%42`!,24)2
M05)97U!!5$@`````1%E,1%],24)205)97U!!5$@`````````4TA,24)?4$%4
M2````````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D
M0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C
M:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP
M9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&
M:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I
M;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M
M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R
M7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@
M/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E
M;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM
M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A8
M6"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*
M4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@
M(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M
M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N
M"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B
M("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I
M;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU
M;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q
M*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU
M<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA
M;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PII9B`H97AI<W1S("1%3E9[
M4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["D!!4D=6(#T@
M;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]
M("T@,2D["B0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*9F]R("AK
M97ES("5%3E8I('L*9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*
M?0I]"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@
M/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE
M*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O
M<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(
M+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B
M=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@-3$R
M.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ92!I
M9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O<B!D
M:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@)&YR
M96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR96%D(&9A
M:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@)&]F
M9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL87-T
M(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S970@
M/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@)&ED
M>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O9F9S
M970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S970@
M+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D
M871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW
M:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE
M(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN
M+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI
M+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D
M8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F
M+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD
M969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O
M:2D@>PIM>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D
M8W)C*3L*:68@*"1O=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D
M8G5F.PIC;&]S92`D;W5T.PIC:&UO9"`P-S4U+"`D9FEL96YA;64["GT*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64[
M"GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I
M;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2`B)$5.5GM0
M05)?5$5-4'TO)&)A<V5N86UE)&5X="(["F]U=',H(E-(3$E".B`D9FEL96YA
M;65<;B(I.PIO<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D
M(3L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D;W5T
M.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(
M96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L
M"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&
M2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@
M)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D
M=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D
M=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?
M;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?
M.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN
M960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D
M97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N
M9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT
M("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R
M;B`D9F@["GT*96QS92!["FUY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H
M)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PII9B`H)&]U="D@>PIB:6YM;V1E
M*"1O=70I.PIP<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["F-L;W-E("1O
M=70["GT*;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PIB:6YM
M;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A
M:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R
M<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE
M("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=
M*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O
M0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q
M=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@
M)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E
M("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F
M(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T
M.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U
M:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P
M;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI
M('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS
M=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V
M97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U
M<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI
M9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY
M($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM
M*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=)
M)RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG
M*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H
M:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T
M(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G
M.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L
M<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@
M)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N
M;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C
M:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D
M9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET
M7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F
M;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC
M.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D
M>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU
M;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D
M:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R
M<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M
M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@
M<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]
M?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I
M92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@
M82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#
M<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U
M="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I
M('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I
M;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A
M7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C
M86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D
M97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH
M7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E
M;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V
M86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.
M5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N
M('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]
M>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H
M*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD
M968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E
M7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P
M('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I
M=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O
M<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#
M.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@
M)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N
M86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA
M;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?
M.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI
M('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H
M;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@
M/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA
M;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B
M*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]
M"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T
M96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^
M("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG
M("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N
M+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N
M="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F
M:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)
M3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF
M("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX
M?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L
M>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N
M(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P
M<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H
M)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N
M9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z
M:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA
M;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N
M86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T
M>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^
M;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E
M<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U
M.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@
M>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S
M:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C
M='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF
M("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D
M9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C
M:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["GT*
M)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M
M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE
M7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG
M=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M
M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I
M<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q
M=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN
M97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z
M("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP
M=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O
M9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T
M<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A
M="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB
M97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M
M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE
M;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*
M*%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T
M7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D
M97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D
M;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN
M9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B
M)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D
M;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R
M86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T
M7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2
M.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!
M4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO
M9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@
M72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@
M)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A
M=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64[
M"FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE
M.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0
M871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T
M:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO
M9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U
M:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S
M.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E
M($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*
M<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I
M<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R
M97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!]
M.PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A
M;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![
M(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V
M86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H
M(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U0
M1$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@
M*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@
M86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![
M*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H
M(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F
M5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*
M)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6
M>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R
M;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG
M>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@
M)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D
M;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L
M("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D
M9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K
M("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@
M<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@
M+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A
M;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*
M;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/
M3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?
M=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L
M(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM
M>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA
M9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S
M="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%2
M7T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP
M+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?
M=&5M<&9I;&4@>PIM>2`H)&5X="P@)&-R8RD@/2!`7SL*;7D@*"1F:"P@)&9I
M;&5N86UE*3L*)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["FEF
M("@D14Y6>U!!4E]#3$5!3GTI('L*=6YL:6YK("1F:6QE;F%M92!I9B`M92`D
M9FEL96YA;64["G!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*?0IE;'-E('L*
M<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*
M?0IO<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E
M*"1F:"D["G)E='5R;B@D9F@L("1F:6QE;F%M92D["GT*<W5B(%]S971?<')O
M9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%
M3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$[
M"GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I
M;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G
M;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%
M?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@
M>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I
M9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@
M>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R
M96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@
M)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A
M;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I
M9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H
M)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@
M;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]
M"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.
M5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W
M9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D
M*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P
M<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P
M=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.
M251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM0
M05)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@
M0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*
M9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-
M4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!
M4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD
M7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@
M("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.
M5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!
M3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R
M("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@
M)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*
M<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@
M(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I
M;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L
M(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV
M;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V
M96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU
M;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A
M<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP
M="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU
M;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H
M)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I
M9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H
M)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````X)0```````/`D```````````````````!``````````$`
M`````````0````````#?`0````````$`````````Z@$````````!````````
M`/0!`````````0````````!#`@````````$`````````G@,````````!````
M`````,8#````````#`````````"@'0````````T`````````!%4````````9
M`````````.B:`0``````&P`````````(`````````!H`````````\)H!````
M```<``````````@`````````]?[_;P````!@`@````````4`````````N`T`
M```````&`````````%`#````````"@`````````K!0````````L`````````
M&``````````5`````````````````````P````````!0G0$```````(`````
M``````8````````4``````````<`````````%P````````"@%P````````<`
M````````*!0````````(`````````'@#````````"0`````````8````````
M`!@```````````````````#[__]O``````$```@`````_O__;P````#($P``
M`````/___V\``````P````````#P__]O`````.02````````^?__;P`````7
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````P!T```````#`'0```````,`=````````
MP!T```````#`'0```````,`=````````P!T```````#`'0```````,`=````
M````P!T```````#`'0```````,`=````````P!T```````#`'0```````,`=
M````````P!T```````#`'0```````,`=````````P!T```````#`'0``````
M`,`=````````P!T```````#`'0```````,`=````````P!T```````#`'0``
M`````,`=````````P!T```````#`'0```````,`=````````P!T```````#`
M'0```````,`=````````P!T```````#`'0```````,`=````````P!T`````
M``#`'0```````,`=````````P!T```````#`'0```````,`=````````P!T`
M``````#`'0```````,`=````````P!T```````#`'0```````,`=````````
MP!T```````#`'0```````,`=````````P!T```````#`'0```````,`=````
M````P!T```````#`'0```````,`=````````P!T```````#`'0```````,`=
M````````P!T```````#`'0```````,`=````````P!T`````````FP$`````
M``!5````````````````````````````````````````````````````````
M``````````````````````````````````````B@`0````````````````"(
M5```````````````````X"$`````````````````````````````````````
M````````````````````````"*`!``````#_____`````#!9````````0%D`
M``````!(60```````%!9````````6%D```````!P60``````````````````
M*%D```````#`50``````````````````T%8````````(60```````!!9````
M````&%D````````@60``````````````````\%@```````#X6```````````
M````````@%D```````!'0T,Z("A$96)I86X@-BXR+C`M-"D@-BXR+C`@,C`Q
M-C`Y,30`1T-#.B`H1&5B:6%N(#8N,BXP+3,I(#8N,BXP(#(P,38P.3`Q```N
M<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL
M9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N
M9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT
M`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R
M<F%Y`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT````
M````````````````````````````````````````````````````````````
M``````````````````````````````L````!`````@```````````@``````
M```"````````&P````````````````````$````````````````````3````
M!P````(`````````'`(````````<`@```````"`````````````````````$
M````````````````````(0````<````"`````````#P"````````/`(`````
M```D````````````````````!````````````````````#0```#V__]O`@``
M``````!@`@```````&`"````````[``````````%``````````@`````````
M```````````^````"P````(`````````4`,```````!0`P```````&@*````
M````!@````,````(`````````!@`````````1@````,````"`````````+@-
M````````N`T````````K!0```````````````````0``````````````````
M`$X```#___]O`@````````#D$@```````.02````````W@`````````%````
M``````(``````````@````````!;````_O__;P(`````````R!,```````#(
M$P```````&``````````!@````,````(````````````````````:@````0`
M```"`````````"@4````````*!0```````!X`P````````4`````````"```
M```````8`````````'0````$````0@````````"@%P```````*`7````````
M``8````````%````%0````@`````````&`````````!^`````0````8`````
M````H!T```````"@'0```````!0````````````````````$````````````
M````````>0````$````&`````````,`=````````P!T````````@!```````
M````````````$``````````0`````````(0````!````!@````````#@(0``
M`````.`A````````)#,```````````````````@```````````````````"*
M`````0````8`````````!%4````````$50```````!``````````````````
M```$````````````````````D`````$````"`````````!A5````````&%4`
M``````#H00``````````````````"````````````````````)@````!````
M`@``````````EP````````"7````````!`````````````````````0`````
M``````````````"B````#@````,`````````Z)H!``````#HF@````````@`
M```````````````````(``````````@`````````K@````\````#````````
M`/":`0``````\)H````````(````````````````````"``````````(````
M`````+H````!`````P````````#XF@$``````/B:````````"```````````
M``````````@```````````````````"_````!@````,``````````)L!````
M````FP```````%`"````````!@`````````(`````````!``````````R```
M``$````#`````````%"=`0``````4)T```````"P`@``````````````````
M"``````````(`````````,T````!`````P``````````H`$```````"@````
M````N`````````````````````@```````````````````#3````"`````,`
M````````N*`!``````"XH````````#`0```````````````````(````````
M````````````V`````$````P````````````````````N*````````!*````
M`````````````````0`````````!``````````$````#````````````````
M``````````*A````````X0````````````````````$`````````````````
"````
